.. pydas documentation master file, created by
   sphinx-quickstart on Fri Feb 13 10:49:07 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pydas's documentation!
=================================

Contents:

.. toctree::
   :maxdepth: 2

   intro
   quickstart

.. automodule:: pydas
   :members:
.. automodule:: pydas.core
   :members:
.. automodule:: pydas.drivers
   :members:

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

